#!/bin/bash
#
# author           : George Vlahavas (vlahavas~AT~gmail~DOT~com, gapan@zenwalk forums)
# project web page : http://cubeengine.com/
# source           : http://downloads.sourceforge.net/cube/cube_2005_08_29_unix.tar.gz

# Package name
NAME="cube"
# Package version
VERSION="2005_08_29"
# Source code URL
SOURCE="http://downloads.sourceforge.net/cube/cube_$VERSION_unix.tar.gz"
# ./configure options
CONFIGOPTIONS="--prefix=/usr"
# Files that should be placed in /usr/doc/package-version/
DOCS="readme.html docs"

CWD=`pwd`
PKG="$CWD/$NAME-install"
ARCH="i486"
CPU="i686"
BUILD="48.1"

rm -rf $PKG
mkdir -p $PKG

# Create package install directory
mkdir $PKG/install

# Create the slack-desc file
cat > $PKG/install/slack-desc << END
$NAME: Cube - an open source first person shooter game
$NAME:
$NAME: Cube is an open source multiplayer and singleplayer first person
$NAME: shooter game built on an entirely new and very unconventional
$NAME: engine. Cube is a landscape-style engine that pretends to be an
$NAME: indoor FPS engine, which combines very high precision dynamic
$NAME: occlusion culling with a form of geometric mipmapping on the whole
$NAME: world for dynamic LOD for configurable fps & graphic detail on most
$NAME: machines. Uses OpenGL & SDL.
$NAME:
$NAME:
END

# Check to see if source is present. If it's not, download it
rm -rf $NAME
if [ -f $NAME\_$VERSION\_unix.tar.gz ]; then
	echo "Source file already here, no need to download";
else
 	echo "Downloading source"
	wget -c $SOURCE
fi

# Check to see if an icon is present. If it's not, download it
if [ -f $NAME.png ]; then
	echo "PNG icon file already here, no need to download";
else
 	echo "Downloading icon file"
	wget -c http://users.zenwalk.org/user-accounts/gapan/$NAME/$NAME.png
fi
if [ -f $NAME.svg ]; then
	echo "SVG icon file already here, no need to download";
else
 	echo "Downloading icon file"
	wget -c http://users.zenwalk.org/user-accounts/gapan/$NAME/$NAME.svg
fi


# Check to see if the configuration files are present. If they're not, download them
if [ -f config.cfg ]; then
	echo "config.cfg already here, no need to download";
else
 	echo "Downloading config.cfg"
	wget -c http://users.zenwalk.org/user-accounts/gapan/$NAME/config.cfg
fi
if [ -f servers.cfg ]; then
	echo "servers.cfg already here, no need to download";
else
 	echo "Downloading servers.cfg"
	wget -c http://users.zenwalk.org/user-accounts/gapan/$NAME/servers.cfg
fi

# Unpack source
tar xvzf $NAME\_$VERSION\_unix.tar.gz

# Create the desktop entry
mkdir -p $PKG/usr/share/applications
cat > $PKG/usr/share/applications/$NAME.desktop <<EOF
[Desktop Entry]
Encoding=UTF-8
Name=Cube
Exec=cube_unix
Terminal=false
Type=Application
Categories=Game;ActionGame;
Icon=cube
EOF

# Just copy stuff
cd $NAME
mkdir -p $PKG/usr/share/cube
cp -a autoexec.cfg bin_unix data demos packages savegames screenshots $PKG/usr/share/cube
mkdir -p $PKG/usr/bin
cp -a cube_unix $PKG/usr/bin
# Tell the launch script to look in the right dir
sed -i -e 's,CUBE_DIR=\.,CUBE_DIR=/usr/share/cube,' $PKG/usr/bin/cube_unix

# Remove some unwanted files
rm $PKG/usr/share/$NAME/bin_unix/freebsd*

# Strip binaries
cd $PKG
find . | xargs file | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null

# Copy Docs
mkdir -p $PKG/usr/doc/$NAME-$VERSION
cd $CWD/$NAME
cp -a $DOCS $PKG/usr/doc/$NAME-$VERSION
mv $PKG/usr/share/$NAME/bin_unix/readme.txt $PKG/usr/doc/$NAME-$VERSION

# Copy icon to the right place
mkdir -p $PKG/usr/share/icons/hicolor/48x48/apps
cp -a $CWD/$NAME.png $PKG/usr/share/icons/hicolor/48x48/apps
mkdir -p $PKG/usr/share/icons/hicolor/scalable/apps
cp -a $CWD/$NAME.svg $PKG/usr/share/icons/hicolor/scalable/apps

# Copy configuration files
cp -a $CWD/config.cfg $PKG/usr/share/$NAME
cp -a $CWD/servers.cfg $PKG/usr/share/$NAME

# Add the build-file in the package
mkdir -p $PKG/usr/src/$NAME-$VERSION
cp "$CWD/build-$NAME.sh" "$PKG/usr/src/$NAME-$VERSION/build-$NAME.sh"
chmod a+x "$PKG/usr/src/$NAME-$VERSION/build-$NAME.sh"

# Make sure ownerships and permissions are sane
cd $PKG
chown -R root:root .
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

# But some files and directories need to be writable by everyone
chmod a+w $PKG/usr/share/$NAME/autoexec.cfg
chmod a+w $PKG/usr/share/$NAME/config.cfg
chmod a+w $PKG/usr/share/$NAME/servers.cfg
chmod -R a+w $PKG/usr/share/$NAME/savegames
chmod -R a+w $PKG/usr/share/$NAME/screenshots

# Make the package
makepkg -l y -c n $CWD/$NAME-$VERSION-$ARCH-$BUILD.tgz

# Calculate md5sum
cd $CWD/
md5sum $NAME-$VERSION-$ARCH-$BUILD.tgz > $NAME-$VERSION-$ARCH-$BUILD.md5

# Remove source-code and temporary install directories
# since they are not needed anymore
rm -rf $CWD/$NAME
rm -rf $PKG
